---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Please fill in the information below so that we can solve the problem quickly, Thanks !**
**(请将下面信息填写完整，便于我们快速解决问题，谢谢！)**

**Describe the bug**
**问题描述**
A clear and concise description of what the bug is.
(请在此处详细的描述报错信息)



**Informations (please complete the following information):**
 - Inference engine for deployment(用于部署的推理引擎):
 - Why convert to onnx(为什么需要转换为ONNX格式)：
 - OS(操作系统): 
 - Paddle Version(Paddle版本):
 - Paddle2ONNX Version(Paddle2ONNX版本):
 - Email/Wechat/Phone(你的联系方式):

**To Reproduce**
**复现步骤**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error



**Expected behavior**
**预期结果**
A clear and concise description of what you expected to happen.



**Screenshots**
**报错截图**
If applicable, add screenshots to help explain your problem.



**Additional context**
**其他信息**
Add any other context about the problem here.
